@@ -8,6 +8,6 @@ INCLUDES="$INCLUDES -include glibconfig.cpp"
 cpp -P -DINCLUDE_INTERNAL_SYMBOLS -DINCLUDE_VARIABLES -DG_STDIO_NO_WRAP_ON_UNIX -DALL_FILES $INCLUDES "${srcdir:-.}/glib.symbols" | sed -e '/^$/d' -e 's/ G_GNUC.*$//' -e 's/ PRIVATE$//' | sort > expected-abi
 rm glibconfig.cpp
 
-nm -D .libs/libglib-2.0.so | grep " [BDTR] " | cut -d ' ' -f 3 | sort > actual-abi
+nm -D -g --defined-only .libs/libglib-2.0.so | cut -d ' ' -f 3 | sort > actual-abi
 
 diff -u expected-abi actual-abi && rm expected-abi actual-abi
