@@ -196,6 +196,8 @@ g_iconv_close (GIConv converter)
 }
 
 
+#ifdef NEED_ICONV_CACHE
+
 #define ICONV_CACHE_SIZE   (16)
 
 struct _iconv_cache_bucket {
@@ -463,6 +465,47 @@ close_converter (GIConv converter)
   return 0;
 }
 
+#else  /* !NEED_ICONV_CACHE */
+
+static GIConv
+open_converter (const gchar *to_codeset,
+		const gchar *from_codeset,
+		GError     **error)
+{
+  GIConv cd;
+
+  cd = g_iconv_open (to_codeset, from_codeset);
+
+  if (cd == (GIConv) -1)
+    {
+      /* Something went wrong.  */
+      if (error)
+	{
+	  if (errno == EINVAL)
+	    g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_NO_CONVERSION,
+			 _("Conversion from character set '%s' to '%s' is not supported"),
+			 from_codeset, to_codeset);
+	  else
+	    g_set_error (error, G_CONVERT_ERROR, G_CONVERT_ERROR_FAILED,
+			 _("Could not open converter from '%s' to '%s'"),
+			 from_codeset, to_codeset);
+	}
+    }
+  
+  return cd;
+}
+
+static int
+close_converter (GIConv cd)
+{
+  if (cd == (GIConv) -1)
+    return 0;
+  
+  return g_iconv_close (cd);  
+}
+
+#endif /* NEED_ICONV_CACHE */
+
 /**
  * g_convert_with_iconv:
  * @str:           the string to convert
@@ -544,6 +587,7 @@ g_convert_with_iconv (const gchar *str,
 	    {
 	    case EINVAL:
 	      /* Incomplete text, do not report an error */
+	      done = TRUE;
 	      break;
 	    case E2BIG:
 	      {
@@ -1952,7 +1996,8 @@ make_valid_utf8 (const gchar *name)
 	string = g_string_sized_new (remaining_bytes);
 
       g_string_append_len (string, remainder, valid_bytes);
-      g_string_append_c (string, '?');
+      /* append U+FFFD REPLACEMENT CHARACTER */
+      g_string_append (string, "\357\277\275");
       
       remaining_bytes -= valid_bytes + 1;
       remainder = invalid + 1;
@@ -1962,7 +2007,6 @@ make_valid_utf8 (const gchar *name)
     return g_strdup (name);
   
   g_string_append (string, remainder);
-  g_string_append (string, " (invalid encoding)");
 
   g_assert (g_utf8_validate (string->str, -1, NULL));
   
@@ -1976,7 +2020,13 @@ make_valid_utf8 (const gchar *name)
  * Returns the display basename for the particular filename, guaranteed
  * to be valid UTF-8. The display name might not be identical to the filename,
  * for instance there might be problems converting it to UTF-8, and some files
- * can be translated in the display
+ * can be translated in the display.
+ *
+ * If GLib can not make sense of the encoding of @filename, as a last resort it 
+ * replaces unknown characters with U+FFFD, the Unicode replacement character.
+ * You can search the result for the UTF-8 encoding of this character (which is
+ * "\357\277\275" in octal notation) to find out if @filename was in an invalid
+ * encoding.
  *
  * You must pass the whole absolute pathname to this functions so that
  * translation of well known locations can be done.
@@ -2007,13 +2057,17 @@ g_filename_display_basename (const gchar *filename)
  * g_filename_display_name:
  * @filename: a pathname hopefully in the GLib file name encoding
  * 
- * Converts a filename into a valid UTF-8 string. The 
- * conversion is not necessarily reversible, so you 
- * should keep the original around and use the return
- * value of this function only for display purposes.
- * Unlike g_filename_to_utf8(), the result is guaranteed 
- * to be non-NULL even if the filename actually isn't in the GLib
- * file name encoding.
+ * Converts a filename into a valid UTF-8 string. The conversion is 
+ * not necessarily reversible, so you should keep the original around 
+ * and use the return value of this function only for display purposes.
+ * Unlike g_filename_to_utf8(), the result is guaranteed to be non-%NULL 
+ * even if the filename actually isn't in the GLib file name encoding.
+ *
+ * If GLib can not make sense of the encoding of @filename, as a last resort it 
+ * replaces unknown characters with U+FFFD, the Unicode replacement character.
+ * You can search the result for the UTF-8 encoding of this character (which is
+ * "\357\277\275" in octal notation) to find out if @filename was in an invalid
+ * encoding.
  *
  * If you know the whole pathname of the file you should use
  * g_filename_display_basename(), since that allows location-based
